import Service from "./common/service.js";
import language from "./common/language.js";
new Vue({
  el: "#app",
  data: {
    total: 0,
    params: {
      page: 1,
      page_num: 5,
      search: "",
    },
    current_item: 0,
    list: [],
    current_info: {
      name: "",
      time: "",
    },
    create_params: {
      position: null, // 职位id
      realname: "", // 姓名
      tel: "", // 电话
      email: "", // 邮箱
      url: "", // 简历
    },
    file_name: "",
    pagination_list: [],
  },
  computed: {
    use_submit() {
      return Object.keys(this.create_params).every(
        (item) => this.create_params[item]
      );
    },
  },
  mounted() {
    this.getList();
  },
  methods: {
    text(val) {
      return language[val][localStorage.getItem("language")];
    },
    lan_key(val) {
      return `${val}${localStorage.getItem("language") == "en" ? "_en" : ""}`;
    },
    // 切换分页
    changeCurrent(val) {
      if (val == this.params.page || val == "...") return;
      if (val < 1 || val > Math.ceil(this.total / this.params.page_num)) return;
      this.params.page = val;
      this.getList();
    },
    setPaginationList() {
      const allNum = Math.ceil(this.total / this.params.page_num);
      this.pagination_list = new Array(allNum)
        .fill(null)
        .map((_, index) => {
          if (index == 0 || index == allNum - 1) return index + 1;
          return Math.abs(index + 1 - this.params.page) >= 2
            ? Math.abs(index + 1 - this.params.page) == 2
              ? "..."
              : ""
            : index + 1;
        })
        .filter((i) => i);
    },
    // 搜素
    search() {
      this.params.page = 1;
      this.getList();
    },
    // 获取数据
    getList() {
      Service.get_position(this.params)
        .then((res) => {
          this.list = res.data;
          // this.current_item = res.data[0] ? this.list[0].id : "";
          this.total = res.total;
          this.setPaginationList();
        })
        .catch((err) => {
          console.log(err);
        });
    },
    // 申请
    setSubmitInfo(item) {
      if (!item) {
        this.current_info = {
          name: "",
          time: "",
        };
        this.create_params = {
          position: null, // 职位id
          realname: "", // 姓名
          tel: "", // 电话
          email: "", // 邮箱
          url: "", // 简历
        };
        this.file_name = "";
        return;
      }
      this.create_params.position = this.current_info.name =
        item[this.lan_key("name")];
      this.current_info.name = item[this.lan_key("name")];
      this.current_info.time = item.time;
    },
    // 上传简历
    uploadFile({ target }) {
      const file = target.files[0];
      const formData = new FormData();
      formData.append("file", file);
      Service.upload(formData)
        .then((res) => {
          this.file_name = file.name;
          this.create_params.url = res.url;
        })
        .catch((err) => {
          console.log(err);
        });
    },
    // 提交
    submit() {
      if (!this.use_submit) return;
      Service.create_position(this.create_params)
        .then((res) => {
          Object.keys(this.create_params).forEach(
            (key) => (this.create_params[key] = "")
          );
          alert(this.text("提交成功"));
        })
        .catch((err) => {
          console.log(err);
        });
    },
  },
});
